# upk2esphome

This website allows you to generate ESPHome YAML Configuration based on `user_param_key` parameters, used in many Tuya smart devices.

A live, web version is deployed on GitHub Pages at [https://upk.libretiny.eu/](https://upk.libretiny.eu/).

Since v4.1.0, [ltchiptool](https://docs.libretiny.eu/docs/flashing/tools/ltchiptool/) contains a GUI that can generate ESPHome configs (based on this program). It can also grab configuration data from [ESPHome-Kickstart](https://github.com/libretiny-eu/esphome-kickstart).
